TextHUD_UpdateRate = 0.066;

function TextHUD_OnUpdate(self, elapsed)
	self.TimeSinceLastUpdate = self.TimeSinceLastUpdate + elapsed;
	if (self.TimeSinceLastUpdate > TextHUD_UpdateRate) then
		TextHUD_UpdateAll();
		self.TimeSinceLastUpdate = 0;
	end
end

function TextHUD_UpdateAll()
	TextHUD_PlayerNameTextUpdate();
	TextHUD_PlayerHealthTextUpdate();
	TextHUD_PlayerManaTextUpdate();

	TextHUD_PetNameTextUpdate();
	TextHUD_PetHealthTextUpdate();
	TextHUD_PetManaTextUpdate();
end

function TextHUD_PlayerNameTextUpdate()
	TextHUD_PlayerNameText:SetText(UnitName("player"));
	local playerClass, englishClass = UnitClass("player");
	TextHUD_PlayerNameText:SetTextColor(RAID_CLASS_COLORS[englishClass].r, RAID_CLASS_COLORS[englishClass].g, RAID_CLASS_COLORS[englishClass].b);
end

function TextHUD_PlayerHealthTextUpdate()
	TextHUD_PlayerHealthText:SetText(string.format("%4.0f", UnitHealth("player") / UnitHealthMax("player") * 100));
	local healthColor = TextHUD_SetHealthColor(UnitHealth("player") / UnitHealthMax("player") * 100);
	TextHUD_PlayerHealthText:SetTextColor(healthColor.r, healthColor.g, healthColor.b);
end

function TextHUD_PlayerManaTextUpdate()
	classDisplayName, class, classID = UnitClass("player");
	local power = UnitPowerType("player");
	local combo = "";
	local mana = nil;
	local name, rank, icon, count;

	if power == 0 then -- Mana
		if classID == 2 then -- Paladin
			count = UnitPower("player", 9); -- Holy Power
			if count ~= 0 then
				combo = "/"..count;
			end
		elseif classID == 5 then -- Priest
			count = UnitPower("player", 13); -- Shadow Orbs
			if count ~= 0 then
				combo = "/"..count;
			end
		elseif classID == 7 then -- Shaman
			local currentSpec = GetSpecialization();
			if currentSpec == 1 then -- Elemental
				name, rank, icon, count = UnitAura("player", "Lightning Shield", nil, "HELPFUL");
			elseif currentSpec == 2 then -- Enhancement
				name, rank, icon, count = UnitAura("player", "Maelstrom Weapon", nil, "HELPFUL");
			end
			if count ~= nil then
				combo = "/"..count;
			end
		elseif classID == 8 then -- Mage
			name, rank, icon, count = UnitAura("player", "Arcane Charge", nil, "HARMFUL");
			if count ~= nil then
				combo = "/"..count;
			end
		elseif classID == 9 then -- Warlock
			local currentSpec = GetSpecialization();
			if currentSpec == 1 then -- Affliction
				count = UnitPower("player", 7); -- Soul Shards
			elseif currentSpec == 2 then -- Demonology
				count = UnitPower("player", 15); -- Demonic Fury
			elseif currentSpec == 3 then -- Destruction
				count = UnitPower("player", 14); -- Burning Embers
			else -- No Spec
				count = 0;
			end
			if count ~= 0 then
				combo = "/"..count;
			end
		elseif classID == 10 then -- Monk
			count = UnitPower("player", 12);
			if count ~= 0 then
				combo = "/"..count;
			end
		elseif classID == 11 then -- Druid
			local currentSpec = GetSpecialization();
			if currentSpec == 1 then -- Balance
				count = UnitPower("player", 8); -- Eclipse
				if count ~= 0 then
					combo = "/"..count;
				end
			end
		end
		mana = string.format("%4.0f", UnitPower("player") / UnitPowerMax("player") * 100);
	elseif power == 3 then -- Energy
		if classID == 10 then -- Monk
			count = UnitPower("player", 12);
		else
			count = GetComboPoints("player");
		end
		if count ~= 0 then
			combo = "/"..count;
		end
	elseif (power == 17 or power == 18) then -- Fury or Pain
		mana = UnitPower("player", power);
	end

	if mana == nil then
		mana = UnitPower("player");
	end

	TextHUD_PlayerManaText:SetText(mana..combo);

	local manaColor = TextHUD_SetManaColor(UnitPower("player") / UnitPowerMax("player") * 100);
	TextHUD_PlayerManaText:SetTextColor(manaColor.r, manaColor.g, manaColor.b);
end

function TextHUD_PetNameTextUpdate()
	if UnitExists("pet") then
		TextHUD_PetNameText:SetText(UnitName("pet"));
		local playerClass, englishClass = UnitClass("pet");
		if englishClass ~= nil then
			TextHUD_PetNameText:SetTextColor(RAID_CLASS_COLORS[englishClass].r, RAID_CLASS_COLORS[englishClass].g, RAID_CLASS_COLORS[englishClass].b);
		end
	else
		TextHUD_PetNameText:SetText("");
	end
end

function TextHUD_PetHealthTextUpdate()
	if UnitExists("pet") then
		TextHUD_PetHealthText:SetText(string.format("%4.0f", UnitHealth("pet") / UnitHealthMax("pet") * 100));
		local healthColor = TextHUD_SetHealthColor(UnitHealth("pet") / UnitHealthMax("pet") * 100);
		TextHUD_PetHealthText:SetTextColor(healthColor.r, healthColor.g, healthColor.b);
	else
		TextHUD_PetHealthText:SetText("");
	end
end

function TextHUD_PetManaTextUpdate()
	if UnitExists("pet") then
		TextHUD_PetManaText:SetText(string.format("%4.0f", UnitPower("pet") / UnitPowerMax("pet") * 100));
		local manaColor = TextHUD_SetManaColor(UnitPower("pet") / UnitPowerMax("pet") * 100);
		TextHUD_PetManaText:SetTextColor(manaColor.r, manaColor.g, manaColor.b);
	else
		TextHUD_PetManaText:SetText("");
	end
end

function TextHUD_SetHealthColor(health)
	local returnColor = { r = 0, g = 0, b = 0 };
	if (health >= 100) then			-- white
		returnColor.r = 1;
		returnColor.g = 1;
		returnColor.b = 1;
	elseif (health > 80) then		-- green
		returnColor.g = 1;
	elseif (health > 60) then		-- light green
		returnColor.g = 0.75;
	elseif (health > 40) then		-- yellow
		returnColor.r = 1;
		returnColor.g = 1;
	elseif (health >= 20) then		-- red
		returnColor.r = 1;
		returnColor.g = 0.45;
	elseif (health > 0) then		-- red
		returnColor.r = 1;
		returnColor.g = 0.1;
		returnColor.b = 0.1;
	else							-- gray
		returnColor.r = 0.5;
		returnColor.g = 0.5;
		returnColor.b = 0.5;
	end
	
	return returnColor;
end

function TextHUD_SetManaColor(mana)
	local returnColor = { r = 0, g = 0, b = 0 };

	if (mana >= 100) then			-- white
		returnColor.r = 1;
		returnColor.g = 1;
		returnColor.b = 1;
	elseif (mana >= 60) then		-- green
		returnColor.g = 1;
	elseif (mana >= 40) then		-- light green
		returnColor.g = 0.75;
	elseif (mana >= 30) then		-- dirty yellow
		returnColor.r = 0.75;
		returnColor.g = 0.75;
	elseif (mana >= 15) then		-- light blue
		returnColor.b = 1;
		returnColor.g = 1;
	elseif (mana > 0) then			-- darker blue
		returnColor.g = 0.75;
		returnColor.b = 1;
	else							-- gray
		returnColor.r = 0.5;
		returnColor.g = 0.5;
		returnColor.b = 0.5;
	end

	return returnColor;
end